### Name: patt.design
### Title: Paired Comparison Patterns - Design Matrix Generation
### Aliases: patt.design
### Keywords: models regression

### ** Examples


## mini example with three Likert items
## and two subject covariates

data(xmpl)   # example data in package
dsgnmat <- patt.design(xmpl, nitems = 3, resptype="rating",
    blnIntcovs = TRUE, cov.sel="ALL")
print(head(dsgnmat))

## ILLUSTRATING THE ISSP2000 EXAMPLE
##   simplified version of the analysis as
##   given in Dittrich et.al.(2007)

data(issp2000)

design <- patt.design(issp2000, nitems=6, resptype="rating",
      cov.sel=c("SEX","EDU"))

#  - fit null multinomial model (basic model for items without
#    subject covariates) through Poisson distribution.
#  - SEX:EDU parameters are nuisance parameters
#  - the last item (GENE) becomes a reference item
#    in the model and is aliased; all other items
#    are compared to this last item

# item parameters with undecided effects and no covariate effects.

summary(glm(y~SEX*EDU + CAR+IND+FARM+WATER+TEMP+GENE
                + u12+u13+u23+u14+u24+u34+u15+u25+u35+u45+u16+u26+u36+u46+u56,
             family=poisson, data=design))

# now add main effect of SEX on items

summary(glm(y~SEX:EDU + CAR+IND+FARM+WATER+TEMP+GENE
                + (CAR+IND+FARM+WATER+TEMP+GENE):SEX
                + u12+u13+u23+u14+u24+u34+u15+u25+u35+u45+u16+u26+u36+u46+u56,
             family=poisson, data=design))

## Not run: 
##D ## example with control list
##D ## not run because input data file does not exist
##D 
##D # defining the ctrl list
##D # would be typically read from file using source()
##D testex1<-list(
##D    resptype     = "paircomp",
##D    datafile     = "test/test.dat",
##D    nitems       = 5,
##D    blnRevert    = FALSE,
##D    blnReducecat = TRUE,
##D    blnIntcovs   = FALSE,
##D    cov.sel      = c("SEX","URB"),
##D 
##D    blnGLIMcmds  = TRUE,
##D    glimCmdFile  = "test/test.gli",
##D    outFile      = "test/test.design",
##D    intFile      = ""        # since blnIntcovs = FALSE
##D )
##D patt.design(testex1)
## End(Not run)




